macro_rules! error {
($($arg:tt)+) => { ... };
}Expand description
Logs a message at the error level.
Use this macro to log critical failures that prevent a component or the entire application from continuing normal execution.
macro_rules! error {
($($arg:tt)+) => { ... };
}Logs a message at the error level.
Use this macro to log critical failures that prevent a component or the entire application from continuing normal execution.