macro_rules! warn {
($($arg:tt)+) => { ... };
}Expand description
Logs a message at the warn level.
Use this macro to log hazardous situations or anomalies that are not fatal but should be investigated by the operations team.
macro_rules! warn {
($($arg:tt)+) => { ... };
}Logs a message at the warn level.
Use this macro to log hazardous situations or anomalies that are not fatal but should be investigated by the operations team.